@@ -7,7 +7,12 @@ class MongoDS(DataSource):
     def __init__(self, query, collection, database='database',
                  host='localhost', port=27017, user='admin', password='123'):
         super().__init__()
-        self._query = query
+
+        if not isinstance(query, dict):
+            raise TypeError('query must be a dict')
+        else:
+            self._query = query
+
         self.collection = collection
         self.database = database
         self.host = host
@@ -16,8 +21,7 @@ class MongoDS(DataSource):
         self.password = password
 
     def query(self, q):
-        if not isinstance(q, dict):
-            raise TypeError('query must be a dict')
+        assert isinstance(q, dict)
 
         conn = MongoClient(
             host=self.host,
@@ -34,8 +38,4 @@ class MongoDS(DataSource):
         return df, self._make_colmap(df)
 
     def name(self):
-        return '{}: {}/{}'.format(
-            self.__class__.__name__,
-            self.database,
-            self.collection
-        )
+        return 'MongoDB - {}'.format(self._query)
